@@ -109,7 +109,7 @@ static dm_percent_t _data_percent(const struct logical_volume *lv)
 	if (lv_is_cow(lv))
 		return _snap_percent(lv);
 
-	if (lv_is_cache(lv) || lv_is_cache_pool(lv)) {
+	if (lv_is_cache(lv) || lv_is_used_cache_pool(lv)) {
 		if (!lv_cache_status(lv, &status)) {
 			stack;
 			return DM_PERCENT_INVALID;
@@ -130,7 +130,7 @@ static dm_percent_t _metadata_percent(const struct logical_volume *lv)
 	dm_percent_t percent;
 	struct lv_status_cache *status;
 
-	if (lv_is_cache(lv) || lv_is_cache_pool(lv)) {
+	if (lv_is_cache(lv) || lv_is_used_cache_pool(lv)) {
 		if (!lv_cache_status(lv, &status)) {
 			stack;
 			return DM_PERCENT_INVALID;
