@@ -7,7 +7,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #define _REENTRANT
@@ -160,12 +160,18 @@ static int _parse_one(log_state *s, int outlet, const char *type, int enable)
 	if (!strcmp(type, "all"))
 		for (i = 0; i < 32; ++i)
 			daemon_log_enable(s, outlet, i, enable);
+	else if (!strcmp(type, "fatal"))
+		daemon_log_enable(s, outlet, DAEMON_LOG_FATAL, enable);
+	else if (!strcmp(type, "error"))
+		daemon_log_enable(s, outlet, DAEMON_LOG_ERROR, enable);
+	else if (!strcmp(type, "warn"))
+		daemon_log_enable(s, outlet, DAEMON_LOG_WARN, enable);
+	else if (!strcmp(type, "info"))
+		daemon_log_enable(s, outlet, DAEMON_LOG_INFO, enable);
 	else if (!strcmp(type, "wire"))
 		daemon_log_enable(s, outlet, DAEMON_LOG_WIRE, enable);
 	else if (!strcmp(type, "debug"))
 		daemon_log_enable(s, outlet, DAEMON_LOG_DEBUG, enable);
-	else
-		return 0;
 
 	return 1;
 }
