@@ -14,171 +14,17 @@ import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 import unittest
 import sys
-import random
-import string
-import functools
 import time
 import pyudev
 import os
-import xml.etree.ElementTree as Et
-from collections import OrderedDict
+from testlib import *
 
-BUSNAME = "com.redhat.lvmdbus1"
-MANAGER_INT = BUSNAME + '.Manager'
-MANAGER_OBJ = '/' + BUSNAME.replace('.', '/') + 'Manager'
-PV_INT = BUSNAME + ".Pv"
-VG_INT = BUSNAME + ".Vg"
-LV_INT = BUSNAME + ".Lv"
-THINPOOL_INT = BUSNAME + ".ThinPool"
-SNAPSHOT_INT = BUSNAME + ".Snapshot"
-LV_COMMON_INT = BUSNAME + ".LvCommon"
-JOB_INT = BUSNAME + ".Job"
-CACHE_POOL_INT = BUSNAME + ".CachePool"
-CACHE_LV_INT = BUSNAME + ".CachedLv"
+use_session = os.getenv('LVMDBUSD_USE_SESSION', False)
 
-THINPOOL_LV_PATH = '/' + THINPOOL_INT.replace('.', '/')
-
-
-def rs(length, suffix, character_set=string.ascii_lowercase):
-	return ''.join(random.choice(character_set)
-				for _ in range(length)) + suffix
-
-
-bus = dbus.SystemBus(mainloop=DBusGMainLoop())
-
-
-class DbusIntrospection(object):
-	@staticmethod
-	def introspect(xml_representation):
-		interfaces = {}
-
-		root = Et.fromstring(xml_representation)
-
-		for c in root:
-			if c.tag == "interface":
-				in_f = c.attrib['name']
-				interfaces[in_f] = \
-					dict(methods=OrderedDict(), properties={})
-				for nested in c:
-					if nested.tag == "method":
-						mn = nested.attrib['name']
-						interfaces[in_f]['methods'][mn] = OrderedDict()
-
-						for arg in nested:
-							if arg.tag == 'arg':
-								arg_dir = arg.attrib['direction']
-								if arg_dir == 'in':
-									n = arg.attrib['name']
-								else:
-									n = None
-
-								arg_type = arg.attrib['type']
-
-								if n:
-									v = dict(
-											name=mn,
-											a_dir=arg_dir,
-											a_type=arg_type)
-									interfaces[in_f]['methods'][mn][n] = v
-
-					elif nested.tag == 'property':
-						pn = nested.attrib['name']
-						p_access = nested.attrib['access']
-						p_type = nested.attrib['type']
-
-						interfaces[in_f]['properties'][pn] = \
-							dict(p_access=p_access, p_type=p_type)
-					else:
-						pass
-
-		# print('Interfaces...')
-		# for k, v in list(interfaces.items()):
-		#     print('Interface %s' % k)
-		#     if v['methods']:
-		#         for m, args in list(v['methods'].items()):
-		#             print('    method: %s' % m)
-		#             for a, aa in args.items():
-		#                 print('         method arg: %s' % (a))
-		#     if v['properties']:
-		#         for p, d in list(v['properties'].items()):
-		#             print('    Property: %s' % (p))
-		# print('End interfaces')
-
-		return interfaces
-
-
-class RemoteObject(object):
-	def _set_props(self, props=None):
-		# print 'Fetching properties'
-		if not props:
-			# prop_fetch = dbus.Interface(self.bus.get_object(
-			#    BUSNAME, self.object_path), 'org.freedesktop.DBus.Properties')
-
-			for i in range(0, 3):
-				try:
-					prop_fetch = dbus.Interface(self.bus.get_object(
-						BUSNAME, self.object_path),
-						'org.freedesktop.DBus.Properties')
-					props = prop_fetch.GetAll(self.interface)
-					break
-				except dbus.exceptions.DBusException as dbe:
-					if "GetAll" not in str(dbe):
-						raise dbe
-		if props:
-			for kl, vl in list(props.items()):
-				setattr(self, kl, vl)
-
-	def __init__(self, specified_bus, object_path, interface, properties=None):
-		self.object_path = object_path
-		self.interface = interface
-		self.bus = specified_bus
-
-		self.dbus_method = dbus.Interface(specified_bus.get_object(
-			BUSNAME, self.object_path), self.interface)
-
-		self._set_props(properties)
-
-	def __getattr__(self, item):
-		if hasattr(self.dbus_method, item):
-			return functools.partial(self._wrapper, item)
-		else:
-			return functools.partial(self, item)
-
-	def _wrapper(self, _method_name, *args, **kwargs):
-		return getattr(self.dbus_method, _method_name)(*args, **kwargs)
-
-	def update(self):
-		self._set_props()
-
-
-class ClientProxy(object):
-	@staticmethod
-	def _intf_short_name(nm):
-		return nm.split('.')[-1:][0]
-
-	def __init__(self, specified_bus, object_path, interface=None, props=None):
-		i = dbus.Interface(specified_bus.get_object(
-			BUSNAME, object_path), 'org.freedesktop.DBus.Introspectable')
-		self.intro_spect = DbusIntrospection.introspect(i.Introspect())
-
-		for k in self.intro_spect.keys():
-			sn = ClientProxy._intf_short_name(k)
-			# print('Client proxy has interface: %s %s' % (k, sn))
-
-			if interface and interface == k and props is not None:
-				ro = RemoteObject(specified_bus, object_path, k, props)
-			else:
-				ro = RemoteObject(specified_bus, object_path, k)
-
-			setattr(self, sn, ro)
-
-		self.object_path = object_path
-
-	def update(self):
-		# Go through all interfaces and update them
-		for int_f in self.intro_spect.keys():
-			sn = ClientProxy._intf_short_name(int_f)
-			getattr(self, sn).update()
+if use_session:
+	bus = dbus.SessionBus(mainloop=DBusGMainLoop())
+else:
+	bus = dbus.SystemBus(mainloop=DBusGMainLoop())
 
 
 def get_objects():
@@ -312,6 +158,54 @@ class TestDbusService(unittest.TestCase):
 		self.assertTrue(rc == '/')
 		self.assertEqual(self._refresh(), 0)
 
+	def _create_raid5_thin_pool(self, vg=None):
+
+		if not vg:
+			pv_paths = []
+			for pp in self.objs[PV_INT]:
+				pv_paths.append(pp.object_path)
+
+			vg = self._vg_create(pv_paths).Vg
+
+		lv_meta_path = vg.LvCreateRaid(
+			"meta_r5", "raid5", mib(4), 0, 0, -1, {})[0]
+
+		lv_data_path = vg.LvCreateRaid(
+			"data_r5", "raid5", mib(16), 0, 0, -1, {})[0]
+
+		thin_pool_path = vg.CreateThinPool(
+			lv_meta_path, lv_data_path, -1, {})[0]
+
+		# Get thin pool client proxy
+		thin_pool = ClientProxy(self.bus, thin_pool_path)
+
+		return vg, thin_pool
+
+	def test_meta_lv_data_lv_props(self):
+		# Ensure that metadata lv and data lv for thin pools and cache pools
+		# point to a valid LV
+		(vg, thin_pool) = self._create_raid5_thin_pool()
+
+		# Check properties on thin pool
+		self.assertTrue(thin_pool.ThinPool.DataLv != '/')
+		self.assertTrue(thin_pool.ThinPool.MetaDataLv != '/')
+
+		(vg, cache_pool) = self._create_cache_pool(vg)
+
+		self.assertTrue(cache_pool.CachePool.DataLv != '/')
+		self.assertTrue(cache_pool.CachePool.MetaDataLv != '/')
+
+		# Cache the thin pool
+		cached_thin_pool_path = cache_pool.\
+			CachePool.CacheLv(thin_pool.object_path, -1, {})[0]
+
+		# Get object proxy for cached thin pool
+		cached_thin_pool_object = ClientProxy(self.bus, cached_thin_pool_path)
+
+		# Check properties on cache pool
+		self.assertTrue(cached_thin_pool_object.ThinPool.DataLv != '/')
+		self.assertTrue(cached_thin_pool_object.ThinPool.MetaDataLv != '/')
+
 	def _lookup(self, lvm_id):
 		return self.objs[MANAGER_INT][0].Manager.LookUpByLvmId(lvm_id)
 
@@ -360,15 +254,16 @@ class TestDbusService(unittest.TestCase):
 		mgr = self.objs[MANAGER_INT][0].Manager
 
 		# Do a vg lookup
-		path = self.objs[MANAGER_INT][0].Manager.LookUpByLvmId(vg.Name)
+		path = mgr.LookUpByLvmId(vg.Name)
 
 		vg_name_start = vg.Name
+
 		prev_path = path
 		self.assertTrue(path != '/', "%s" % (path))
 
 		# Create some LVs in the VG
 		for i in range(0, 5):
-			lv_t = self._create_lv(size=1024 * 1024 * 16, vg=vg)
+			lv_t = self._create_lv(size=mib(4), vg=vg)
 			full_name = "%s/%s" % (vg_name_start, lv_t.LvCommon.Name)
 			lv_path = mgr.LookUpByLvmId(full_name)
 			self.assertTrue(lv_path == lv_t.object_path)
@@ -419,30 +314,11 @@ class TestDbusService(unittest.TestCase):
 
 	def test_vg_rename_with_thin_pool(self):
 
-		pv_paths = []
-		for pp in self.objs[PV_INT]:
-			pv_paths.append(pp.object_path)
-
-		vg = self._vg_create(pv_paths).Vg
+		(vg, thin_pool) = self._create_raid5_thin_pool()
 
 		vg_name_start = vg.Name
-
 		mgr = self.objs[MANAGER_INT][0].Manager
 
-		# Let's create a thin pool which uses a raid 5 meta and raid5 data
-		# areas
-		lv_meta_path = vg.LvCreateRaid(
-			"meta_r5", "raid5", 1024 * 1024 * 16, 0, 0, -1, {})[0]
-
-		lv_data_path = vg.LvCreateRaid(
-			"data_r5", "raid5", 1024 * 1024 * 512, 0, 0, -1, {})[0]
-
-		thin_pool_path = vg.CreateThinPool(
-			lv_meta_path, lv_data_path, -1, {})[0]
-
-		# Lets create some thin LVs
-		thin_pool = ClientProxy(self.bus, thin_pool_path)
-
 		# noinspection PyTypeChecker
 		self._verify_hidden_lookups(thin_pool.LvCommon, vg_name_start)
 
@@ -450,7 +326,7 @@ class TestDbusService(unittest.TestCase):
 			lv_name = rs(8, '_lv')
 
 			thin_lv_path = thin_pool.ThinPool.LvCreate(
-				lv_name, 1024 * 1024 * 16, -1, {})[0]
+				lv_name, mib(16), -1, {})[0]
 
 			self.assertTrue(thin_lv_path != '/')
 
@@ -504,7 +380,7 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create().Vg
 		self._test_lv_create(
 			vg.LvCreate,
-			(rs(8, '_lv'), 1024 * 1024 * 4,
+			(rs(8, '_lv'), mib(4),
 			dbus.Array([], '(ott)'), -1, {}), vg)
 
 	def test_lv_create_linear(self):
@@ -512,7 +388,7 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create().Vg
 		self._test_lv_create(
 			vg.LvCreateLinear,
-			(rs(8, '_lv'), 1024 * 1024 * 4, False, -1, {}), vg)
+			(rs(8, '_lv'), mib(4), False, -1, {}), vg)
 
 	def test_lv_create_striped(self):
 		pv_paths = []
@@ -522,7 +398,7 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create(pv_paths).Vg
 		self._test_lv_create(
 			vg.LvCreateStriped,
-			(rs(8, '_lv'), 1024 * 1024 * 4, 2, 8, False,
+			(rs(8, '_lv'), mib(4), 2, 8, False,
 			-1, {}), vg)
 
 	def test_lv_create_mirror(self):
@@ -532,7 +408,7 @@ class TestDbusService(unittest.TestCase):
 
 		vg = self._vg_create(pv_paths).Vg
 		self._test_lv_create(vg.LvCreateMirror,
-			(rs(8, '_lv'), 1024 * 1024 * 4, 2, -1, {}), vg)
+			(rs(8, '_lv'), mib(4), 2, -1, {}), vg)
 
 	def test_lv_create_raid(self):
 		pv_paths = []
@@ -542,7 +418,7 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create(pv_paths).Vg
 		self._test_lv_create(vg.LvCreateRaid,
 			(rs(8, '_lv'), 'raid4',
-			1024 * 1024 * 16, 2, 8, -1, {}), vg)
+			mib(16), 2, 8, -1, {}), vg)
 
 	def _create_lv(self, thinpool=False, size=None, vg=None):
 
@@ -554,14 +430,14 @@ class TestDbusService(unittest.TestCase):
 			vg = self._vg_create(pv_paths).Vg
 
 		if size is None:
-			size = 1024 * 1024 * 128
+			size = mib(4)
 
 		return self._test_lv_create(
 			vg.LvCreateLinear,
 			(rs(8, '_lv'), size, thinpool, -1, {}), vg)
 
 	def test_lv_create_rounding(self):
-		self._create_lv(size=1024 * 1024 * 2 + 13)
+		self._create_lv(size=(mib(2) + 13))
 
 	def test_lv_create_thin_pool(self):
 		self._create_lv(True)
@@ -602,7 +478,7 @@ class TestDbusService(unittest.TestCase):
 		tp = self._create_lv(True)
 
 		thin_path = tp.ThinPool.LvCreate(
-			rs(10, '_thin_lv'), 1024 * 1024 * 10, -1, {})[0]
+			rs(10, '_thin_lv'), mib(8), -1, {})[0]
 
 		lv = ClientProxy(self.bus, thin_path)
 		rc = lv.Lv.Rename('rename_test' + lv.LvCommon.Name, -1, {})
@@ -668,9 +544,11 @@ class TestDbusService(unittest.TestCase):
 
 		pv = vg.Pvs
 
-		self._test_lv_create(vg.LvCreate,
-				(rs(8, '_lv'), 1024 * 1024 * 4,
-				dbus.Array([[pv[0], 0, 100]], '(ott)'), -1, {}), vg)
+		pv_proxy = ClientProxy(self.bus, pv[0])
+
+		self._test_lv_create(vg.LvCreate, (rs(8, '_lv'), mib(4),
+			dbus.Array([[pv_proxy.object_path, 0, (pv_proxy.Pv.PeCount - 1)]],
+			'(ott)'), -1, {}), vg)
 
 	def test_lv_resize(self):
 
@@ -679,13 +557,14 @@ class TestDbusService(unittest.TestCase):
 			pv_paths.append(pp.object_path)
 
 		vg = self._vg_create(pv_paths).Vg
-		lv = self._create_lv(vg=vg)
+		lv = self._create_lv(vg=vg, size=mib(16))
 
-		for size in [
-					lv.LvCommon.SizeBytes + 4194304,
-					lv.LvCommon.SizeBytes - 4194304,
-					lv.LvCommon.SizeBytes + 2048,
-					lv.LvCommon.SizeBytes - 2048]:
+		for size in \
+			[
+			lv.LvCommon.SizeBytes + 4194304,
+			lv.LvCommon.SizeBytes - 4194304,
+			lv.LvCommon.SizeBytes + 2048,
+			lv.LvCommon.SizeBytes - 2048]:
 
 			pv_in_use = [i[0] for i in lv.LvCommon.Devices]
 			# Select a PV in the VG that isn't in use
@@ -694,8 +573,10 @@ class TestDbusService(unittest.TestCase):
 			prev = lv.LvCommon.SizeBytes
 
 			if len(pv_empty):
+				p = ClientProxy(self.bus, pv_empty[0])
 				rc = lv.Lv.Resize(
-					size, dbus.Array([[pv_empty[0], 0, 100]], '(oii)'),
+					size,
+					dbus.Array([[p.object_path, 0, p.Pv.PeCount - 1]], '(oii)'),
 					-1, {})
 			else:
 				rc = lv.Lv.Resize(size, dbus.Array([], '(oii)'), -1, {})
@@ -817,17 +698,23 @@ class TestDbusService(unittest.TestCase):
 		# add a number of LVs and then remove the VG and all the contained
 		# LVs which appears to consistently run a little slow.
 
-		vg = self._vg_create(pv_paths).Vg
+		vg_proxy = self._vg_create(pv_paths)
 
 		for i in range(0, num_lvs):
-			obj_path, job = vg.LvCreateLinear(
-				rs(8, "_lv"), 1024 * 1024 * 4, False, -1, {})
-			self.assertTrue(job == '/')
+
+			vg_proxy.update()
+			if vg_proxy.Vg.FreeCount > 0:
+				obj_path, job = vg_proxy.Vg.LvCreateLinear(
+					rs(8, "_lv"), mib(4), False, -1, {})
+				self.assertTrue(job == '/')
+			else:
+				# We ran out of space, test will probably fail
+				break
 
 		# Make sure that we are honoring the timeout
 		start = time.time()
 
-		remove_job = vg.Remove(1, {})
+		remove_job = vg_proxy.Vg.Remove(1, {})
 
 		end = time.time()
 
@@ -902,7 +789,7 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create().Vg
 		lv = self._test_lv_create(
 			vg.LvCreateLinear,
-			(rs(8, '_lv'), 1024 * 1024 * 4, False, -1, {}),
+			(rs(8, '_lv'), mib(4), False, -1, {}),
 			vg)
 
 		t = ['Testing', 'tags']
@@ -968,7 +855,7 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create().Vg
 		self._test_lv_create(
 			vg.LvCreateLinear,
-			(rs(8, '_lv'), 1024 * 1024 * 4, False, -1, {}),
+			(rs(8, '_lv'), mib(4), False, -1, {}),
 			vg)
 
 		vg.update()
@@ -1033,13 +920,16 @@ class TestDbusService(unittest.TestCase):
 
 		mgr = self._manager().Manager
 
-		self.assertEqual(mgr.PvScan(False, True,
-									dbus.Array([], 's'),
-									dbus.Array([], '(ii)'), -1, {}), '/')
+		self.assertEqual(
+			mgr.PvScan(
+				False, True, dbus.Array([], 's'),
+				dbus.Array([], '(ii)'), -1, {}), '/')
 		self.assertEqual(self._refresh(), 0)
-		self.assertEqual(mgr.PvScan(False, False,
-									dbus.Array([], 's'),
-									dbus.Array([], '(ii)'), -1, {}), '/')
+		self.assertEqual(
+			mgr.PvScan(
+				False, False,
+				dbus.Array([], 's'),
+				dbus.Array([], '(ii)'), -1, {}), '/')
 		self.assertEqual(self._refresh(), 0)
 
 		block_path = []
@@ -1062,9 +952,11 @@ class TestDbusService(unittest.TestCase):
 
 		self.assertEqual(self._refresh(), 0)
 
-		self.assertEqual(mgr.PvScan(False, True,
-									dbus.Array([], 's'),
-									mm, -1, {}), '/')
+		self.assertEqual(
+			mgr.PvScan(
+				False, True,
+				dbus.Array([], 's'),
+				mm, -1, {}), '/')
 
 		self.assertEqual(self._refresh(), 0)
 
@@ -1081,9 +973,9 @@ class TestDbusService(unittest.TestCase):
 
 	def test_snapshot_merge(self):
 		# Create a non-thin LV and merge it
-		ss_size = 1024 * 1024 * 512
+		ss_size = mib(8)
 
-		lv_p = self._create_lv(size=1024 * 1024 * 1024)
+		lv_p = self._create_lv(size=mib(16))
 		ss_name = lv_p.LvCommon.Name + '_snap'
 		snapshot_path = lv_p.Lv.Snapshot(ss_name, ss_size, -1, {})[0]
 		ss = ClientProxy(self.bus, snapshot_path)
@@ -1101,7 +993,7 @@ class TestDbusService(unittest.TestCase):
 		tp = self._create_lv(True)
 
 		thin_path = tp.ThinPool.LvCreate(
-			rs(10, '_thin_lv'), 1024 * 1024 * 10, -1, {})[0]
+			rs(10, '_thin_lv'), mib(10), -1, {})[0]
 
 		lv_p = ClientProxy(self.bus, thin_path)
 
@@ -1112,18 +1004,20 @@ class TestDbusService(unittest.TestCase):
 		self.assertTrue(job_path != '/')
 		self._wait_for_job(job_path)
 
-	def _create_cache_pool(self):
-		vg = self._vg_create().Vg
+	def _create_cache_pool(self, vg=None):
 
-		md = self._create_lv(size=(1024 * 1024 * 8), vg=vg)
-		data = self._create_lv(size=(1024 * 1024 * 256), vg=vg)
+		if not vg:
+			vg = self._vg_create().Vg
+
+		md = self._create_lv(size=(mib(8)), vg=vg)
+		data = self._create_lv(size=(mib(8)), vg=vg)
 
 		cache_pool_path = vg.CreateCachePool(
 			md.object_path, data.object_path, -1, {})[0]
 
 		cp = ClientProxy(self.bus, cache_pool_path)
 
-		return (vg, cp)
+		return vg, cp
 
 	def test_cache_pool_create(self):
 
@@ -1137,7 +1031,7 @@ class TestDbusService(unittest.TestCase):
 		for destroy_cache in [True, False]:
 			vg, cache_pool = self._create_cache_pool()
 
-			lv_to_cache = self._create_lv(size=(1024 * 1024 * 1024), vg=vg)
+			lv_to_cache = self._create_lv(size=mib(8), vg=vg)
 
 			c_lv_path = cache_pool.CachePool.CacheLv(
 				lv_to_cache.object_path, -1, {})[0]
@@ -1196,18 +1090,18 @@ class TestDbusService(unittest.TestCase):
 		for c in bad_chars:
 			with self.assertRaises(dbus.exceptions.DBusException):
 				vg_proxy.Vg.LvCreateLinear(rs(8, '_lv') + c,
-					1024 * 1024 * 4, False, -1, {})
+					mib(4), False, -1, {})
 
 		for r in ("_cdata", "_cmeta", "_corig", "_mimage", "_mlog",
 			"_pmspare", "_rimage", "_rmeta", "_tdata", "_tmeta", "_vorigin"):
 			with self.assertRaises(dbus.exceptions.DBusException):
 				vg_proxy.Vg.LvCreateLinear(rs(8, '_lv') + r,
-					1024 * 1024 * 4, False, -1, {})
+					mib(4), False, -1, {})
 
 		for r in ("snapshot", "pvmove"):
 			with self.assertRaises(dbus.exceptions.DBusException):
 				vg_proxy.Vg.LvCreateLinear(r + rs(8, '_lv'),
-					1024 * 1024 * 4, False, -1, {})
+					mib(4), False, -1, {})
 
 	_ALLOWABLE_TAG_CH = string.ascii_letters + string.digits + "._-+/=!:&#"
 
