@@ -30,7 +30,7 @@ static int _pvdisplay_single(struct cmd_context *cmd,
 		size = (uint64_t)(pv_pe_count(pv) - pv_pe_alloc_count(pv)) *
 			pv_pe_size(pv);
 
-	if (arg_count(cmd, short_ARG)) {
+	if (arg_is_set(cmd, short_ARG)) {
 		log_print("Device \"%s\" has a capacity of %s", pv_name,
 			  display_size(cmd, size));
 		goto out;
@@ -44,14 +44,14 @@ static int _pvdisplay_single(struct cmd_context *cmd,
 		log_print_unless_silent("\"%s\" is a new physical volume of \"%s\"",
 					pv_name, display_size(cmd, size));
 
-	if (arg_count(cmd, colon_ARG)) {
+	if (arg_is_set(cmd, colon_ARG)) {
 		pvdisplay_colons(pv);
 		goto out;
 	}
 
 	pvdisplay_full(cmd, pv, NULL);
 
-	if (arg_count(cmd, maps_ARG))
+	if (arg_is_set(cmd, maps_ARG))
 		pvdisplay_segments(pv);
 
 out:
@@ -63,33 +63,33 @@ int pvdisplay(struct cmd_context *cmd, int argc, char **argv)
 	int lock_global = 0;
 	int ret;
 
-	if (arg_count(cmd, columns_ARG)) {
-		if (arg_count(cmd, colon_ARG) || arg_count(cmd, maps_ARG) ||
-		    arg_count(cmd, short_ARG)) {
+	if (arg_is_set(cmd, columns_ARG)) {
+		if (arg_is_set(cmd, colon_ARG) || arg_is_set(cmd, maps_ARG) ||
+		    arg_is_set(cmd, short_ARG)) {
 			log_error("Incompatible options selected");
 			return EINVALID_CMD_LINE;
 		}
 		return pvs(cmd, argc, argv);
 	}
 
-	if (arg_count(cmd, aligned_ARG) ||
-	    arg_count(cmd, all_ARG) ||
-	    arg_count(cmd, binary_ARG) ||
-	    arg_count(cmd, noheadings_ARG) ||
-	    arg_count(cmd, options_ARG) ||
-	    arg_count(cmd, separator_ARG) ||
-	    arg_count(cmd, sort_ARG) ||
-	    arg_count(cmd, unbuffered_ARG)) {
+	if (arg_is_set(cmd, aligned_ARG) ||
+	    arg_is_set(cmd, all_ARG) ||
+	    arg_is_set(cmd, binary_ARG) ||
+	    arg_is_set(cmd, noheadings_ARG) ||
+	    arg_is_set(cmd, options_ARG) ||
+	    arg_is_set(cmd, separator_ARG) ||
+	    arg_is_set(cmd, sort_ARG) ||
+	    arg_is_set(cmd, unbuffered_ARG)) {
 		log_error("Incompatible options selected");
 		return EINVALID_CMD_LINE;
 	}
 
-	if (arg_count(cmd, colon_ARG) && arg_count(cmd, maps_ARG)) {
+	if (arg_is_set(cmd, colon_ARG) && arg_is_set(cmd, maps_ARG)) {
 		log_error("Option -c not allowed with option -m");
 		return EINVALID_CMD_LINE;
 	}
 
-	if (arg_count(cmd, colon_ARG) && arg_count(cmd, short_ARG)) {
+	if (arg_is_set(cmd, colon_ARG) && arg_is_set(cmd, short_ARG)) {
 		log_error("Option -c is not allowed with option -s");
 		return EINVALID_CMD_LINE;
 	}
@@ -99,7 +99,7 @@ int pvdisplay(struct cmd_context *cmd, int argc, char **argv)
 	 * we lock VG_GLOBAL to enable use of metadata cache.
 	 * This can pause alongide pvscan or vgscan process for a while.
 	 */
-	if (!lvmetad_active()) {
+	if (!lvmetad_used()) {
 		lock_global = 1;
 		if (!lock_vol(cmd, VG_GLOBAL, LCK_VG_READ, NULL)) {
 			log_error("Unable to obtain global lock.");
