@@ -237,7 +237,7 @@ int vgrename(struct cmd_context *cmd, int argc, char **argv)
 		}
 	}
 
-	if (!(handle = init_processing_handle(cmd))) {
+	if (!(handle = init_processing_handle(cmd, NULL))) {
 		log_error("Failed to initialize processing handle.");
 		return ECMD_FAILED;
 	}
@@ -246,7 +246,7 @@ int vgrename(struct cmd_context *cmd, int argc, char **argv)
 
 	ret = process_each_vg(cmd, 0, NULL, vg_name_old, NULL,
 			      READ_FOR_UPDATE | READ_ALLOW_EXPORTED,
-			      handle, _vgrename_single);
+			      0, handle, _vgrename_single);
 
 	/* Needed if process_each_vg returns error before calling _single. */
 	if (vp.unlock_new_name)
